@@ -248,11 +248,12 @@ def set_thread_name(name):
 
 
 def find_bins_in_path(bin_name):
-    return [os.path.join(p, bin_name)
-            for p in os.environ.get('PATH', '').split(':')
-            if os.path.isfile(os.path.join(p, bin_name))
-            and (os.name == 'nt' or
-                 os.access(os.path.join(p, bin_name), os.X_OK))]
+    return [
+        os.path.join(p, bin_name)
+        for p in os.environ.get('PATH', '').split(':')
+        if os.path.isfile(os.path.join(p, bin_name)) and (
+            os.name == 'nt' or os.access(os.path.join(p, bin_name), os.X_OK)
+        )]
 
 
 def find_files_by_ext(directory, *exts):
@@ -444,7 +445,8 @@ def get_enabled_plugins() -> dict:
             if plugin:
                 plugins[name] = plugin
         except Exception as e:
-            logger.debug(f'Could not get plugin {name}: {e}')
+            logger.warning(f'Could not initialize plugin {name}')
+            logger.exception(e)
 
     return plugins
 
